@@ -310,7 +310,7 @@ class BigWigTrainer(nn.Module):
 
         if exists(self.train_mouse_head_dl):
             for _ in range(grad_accum_every):
-                seq, target = next(self.train_mouse_house_dl)
+                seq, target = next(self.train_mouse_head_dl)
                 seq, target = seq.cuda(), target.cuda()
 
                 loss = self.model(
@@ -393,7 +393,7 @@ class BigWigTrainer(nn.Module):
                     pred = self.model(seq, head = 'human')
 
                     valid_loss = self.model.loss_fn(pred, target)
-                    valid_corr_coef = pearson_corr_coef(pred, target)
+                    valid_corr_coef = pearson_corr_coef(pred, target).mean()
 
                     log = accum_log(log, {
                         'human_head_valid_loss': valid_loss.item() / grad_accum_every,
@@ -404,11 +404,14 @@ class BigWigTrainer(nn.Module):
 
             if exists(self.valid_mouse_head_dl):
                 for _ in range(grad_accum_every):
-                    seq, target = next(self.valid_mouse_house_dl)
+                    seq, target = next(self.valid_mouse_head_dl)
                     seq, target = seq.cuda(), target.cuda()
 
                     pred = self.model(seq, head = 'mouse')
 
+                    valid_loss = self.model.loss_fn(pred, target)
+                    valid_corr_coef = pearson_corr_coef(pred, target).mean()
+
                     log = accum_log(log, {
                         'mouse_head_valid_loss': valid_loss.item() / grad_accum_every,
                         'mouse_head_valid_corr_coef': valid_corr_coef.item() / grad_accum_every
